@@ -23,6 +23,31 @@
 //! assert_eq!(levenshtein("kitten", "sitting"), 3);
 //! ```
 
+// Strict clippy
+#![warn(
+    clippy::pedantic,
+    clippy::cargo,
+    clippy::nursery,
+    clippy::str_to_string,
+    clippy::missing_inline_in_public_items,
+    clippy::exhaustive_enums,
+    clippy::pattern_type_mismatch
+)]
+// Pedantic config
+#![allow(
+    clippy::missing_panics_doc,
+    clippy::must_use_candidate,
+    clippy::cast_possible_truncation,
+    // Below items are from "restriction"
+    clippy::missing_docs_in_private_items,
+    clippy::expect_used,
+    clippy::unwrap_used,
+    clippy::implicit_return,
+    clippy::integer_arithmetic,
+    clippy::exhaustive_structs,
+    clippy::shadow_unrelated,
+)]
+
 pub mod algorithms;
 pub mod errors;
 pub mod iter;
